==> kie-wb-common-7.4.1.Final-project-sources.tar.gz: kie-wb-common-7.4.1.Final/kie-wb-common-stunner/kie-wb-common-stunner-core/kie-wb-common-stunner-commons/kie-wb-common-stunner-client-common/src/main/java/org/kie/workbench/common/stunner/core/client/session/command/impl/ValidateSessionCommand.java <==
/*
 * Copyright 2017 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.common.stunner.core.client.session.command.impl;

import java.util.Collection;
import javax.enterprise.context.Dependent;
import javax.inject.Inject;

import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
import org.kie.workbench.common.stunner.core.client.session.command.AbstractClientSessionCommand;
import org.kie.workbench.common.stunner.core.client.session.impl.AbstractClientFullSession;
import org.kie.workbench.common.stunner.core.client.validation.canvas.CanvasDiagramValidator;
import org.kie.workbench.common.stunner.core.rule.RuleViolation;
import org.kie.workbench.common.stunner.core.validation.DiagramElementViolation;
import org.kie.workbench.common.stunner.core.validation.Violation;

import static org.uberfire.commons.validation.PortablePreconditions.checkNotNull;

@Dependent
public class ValidateSessionCommand extends AbstractClientSessionCommand<AbstractClientFullSession> {

    private final CanvasDiagramValidator<AbstractCanvasHandler> validator;

    protected ValidateSessionCommand() {
        this(null);
    }

    @Inject
    public ValidateSessionCommand(final CanvasDiagramValidator<AbstractCanvasHandler> validator) {
        super(true);
        this.validator = validator;
    }

    @Override
    @SuppressWarnings("unchecked")
    public <V> void execute(final Callback<V> callback) {
        checkNotNull("callback",
                     callback);
        final AbstractCanvasHandler canvasHandler = getSession().getCanvasHandler();
        validator.validate(canvasHandler,
                           elementViolations -> fireCallback(elementViolations,
                                                             callback));
    }

    @SuppressWarnings("unchecked")
    private <V> void fireCallback(final Collection<DiagramElementViolation<RuleViolation>> violations,
                                  final Callback<V> callback) {
        final boolean areViolations = violations.stream()
                .filter(v -> Violation.Type.ERROR.equals(v.getViolationType()))
                .findAny()
                .isPresent();
        if (!areViolations) {
            callback.onSuccess();
        } else {
            callback.onError((V) violations);
        }
    }
}

==> kie-wb-common-7.6.0.Final-project-sources.tar.gz: kie-wb-common-7.6.0.Final/kie-wb-common-stunner/kie-wb-common-stunner-core/kie-wb-common-stunner-commons/kie-wb-common-stunner-client-common/src/main/java/org/kie/workbench/common/stunner/core/client/session/command/impl/ValidateSessionCommand.java <==
/*
 * Copyright 2017 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.common.stunner.core.client.session.command.impl;

import java.util.Collection;

import javax.enterprise.context.Dependent;
import javax.inject.Inject;

import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
import org.kie.workbench.common.stunner.core.client.session.command.AbstractClientSessionCommand;
import org.kie.workbench.common.stunner.core.client.session.impl.AbstractClientFullSession;
import org.kie.workbench.common.stunner.core.client.validation.canvas.CanvasDiagramValidator;
import org.kie.workbench.common.stunner.core.rule.RuleViolation;
import org.kie.workbench.common.stunner.core.validation.DiagramElementViolation;
import org.kie.workbench.common.stunner.core.validation.Violation;

import static org.kie.soup.commons.validation.PortablePreconditions.checkNotNull;

@Dependent
public class ValidateSessionCommand extends AbstractClientSessionCommand<AbstractClientFullSession> {

    private final CanvasDiagramValidator<AbstractCanvasHandler> validator;

    protected ValidateSessionCommand() {
        this(null);
    }

    @Inject
    public ValidateSessionCommand(final CanvasDiagramValidator<AbstractCanvasHandler> validator) {
        super(true);
        this.validator = validator;
    }

    @Override
    @SuppressWarnings("unchecked")
    public <V> void execute(final Callback<V> callback) {
        checkNotNull("callback",
                     callback);
        final AbstractCanvasHandler canvasHandler = getSession().getCanvasHandler();
        validator.validate(canvasHandler,
                           elementViolations -> fireCallback(elementViolations,
                                                             callback));
    }

    @SuppressWarnings("unchecked")
    private <V> void fireCallback(final Collection<DiagramElementViolation<RuleViolation>> violations,
                                  final Callback<V> callback) {
        final boolean areViolations = violations.stream()
                .filter(v -> Violation.Type.ERROR.equals(v.getViolationType()))
                .findAny()
                .isPresent();
        if (!areViolations) {
            callback.onSuccess();
        } else {
            callback.onError((V) violations);
        }
    }
}
